# ABSTRACT: execute a (built-in) command on remote hosts over SSH
use strict;
use warnings;
package App::rcmd;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::rcmd - execute a (built-in) command on remote hosts over SSH

=head1 VERSION

version 0.005

=head1 SYNOPSIS

This is a stub module, see F<rcmd> script (F<bin/rcmd>) for details.

=head1 INSTALLATION

In case you don't want to use a standard CPAN module installation tool (like
F<cpan> or F<cpanm>) it's enough to copy/paste or download the F<rcmd> script.

=head1 AUTHOR

Jozef Reisinger <reisinge@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Jozef Reisinger.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
